# ----------------------------------------------------------------------------------------
# 					SIMULATION PARAMETERS FOR THE PIC-CODE SMILEI
# ----------------------------------------------------------------------------------------

#					CONFIGURATION FOR UMEA LASER


from math import pi, sqrt, exp, log, cos

# lambda_l = 0.75 micron
# FWHM_I = 0.84932 w0

l0 = 2. * pi             # laser wavelength [in code units], 0.75 mic
t0 = l0                  # optical cycle, lambda_l/c = 2.5 fs
Lsim = [12.*l0, 28.*l0, 28*l0]  # length of the simulation, [9, 21, 21] um
Tsim = (24.0+0.3)*t0             # duration of the simulation, 60 fs
resx = 30.               # nb of cells in one laser wavelength
rest = resx*sqrt(3.)/0.95 # nb of timesteps in one optical cycle 
ts = t0/rest            # timestep
xf = 4.0*l0		# focus distance from xmin, 3 um
w0 = 1.35891*l0              # waist 1.0192 um, i.e. FWHM of Intensity is 1.2 um
a0 = 6.4125                # amplitude, i.e. I = 1.0e20W/cm2
phi = pi/2.0
FWHMtinI = 2.0*t0		# 5 fs
pulse_start = FWHMtinI*2


def time_envelope(t):
#    return 1 # plane wave
    return exp(-2.*log(2.)*(t-xf-pulse_start)**2/FWHMtinI**2)
    
def carrier(t):
    return cos(t + phi)

def space_envelope(y,z):
    return exp(-((y-Lsim[1]/2.0)**2.0+(z-Lsim[2]/2.0)**2.0)/w0**2.0) #gauss
    
def By_profile(y,z,t):
    return 0

def Bz_profile(y,z,t):
    return a0*space_envelope(y,z) * time_envelope(t) * carrier(t)

Main(
    geometry = "3Dcartesian",
    
    interpolation_order = 4 ,
    
    cell_length = [l0/resx,l0/resx, l0/resx],
    grid_length  = Lsim,
    
    number_of_patches = [ 8,8,8 ],
    
    timestep = ts,
    simulation_time = Tsim,
     
   EM_boundary_conditions = [
        ['silver-muller'],
        ['silver-muller'],
        ['silver-muller'],
    ],
    
    random_seed = smilei_mpi_rank
)

LaserOffset(
    box_side               = "xmin",
    space_time_profile     = [ By_profile, Bz_profile ],
    offset                 = xf,
    #extra_envelope          = tconstant(),
    keep_n_strongest_modes = 256,
    angle = 0
)


DiagScalar(
    every = 2.0*rest
)
DiagFields(
    every = 2*rest,
    fields = ['Ex']
)
DiagFields(
    every = 2*rest,
    fields = ['Ey']
)
DiagFields(
    every = 2*rest,
    fields = ['Bz']
)

